@@ -137,7 +137,7 @@ class BaseTest(unittest.TestCase):
         cls.proj.saveProtocol(prot)
 
     @classmethod
-    def _waitOutput(cls, prot, outputAttributeName):
+    def _waitOutput(cls, prot, outputAttributeName, sleepTime=20, timeOut=5000):
         """ Wait until the output is being generated by the protocol. """
 
         def _loadProt():
@@ -153,10 +153,13 @@ class BaseTest(unittest.TestCase):
         counter = 1
         prot2 = _loadProt()
 
+        numberOfSleeps = timeOut/sleepTime
+
         while (not prot2.hasAttribute(outputAttributeName)) and prot2.isActive():
-            time.sleep(5)
+            time.sleep(sleepTime)
             prot2 = _loadProt()
-            if counter > 1000:
+            if counter > numberOfSleeps:
+                print("Timeout (%s) reached waiting for %s at %s" % (timeOut, outputAttributeName, prot))
                 break
             counter += 1
 
